#!/usr/bin/env python
#
# Requires autopep8 to be installed.
# Script for cleaning up most PEP8 related errors checked by the pre-commit hook.
#
import os
import sys

import vtx_common.utils as v_utils

def main():
    cwd = os.getcwd()
    if not v_utils.reqGitDir(cwd):
        print('Must be run from the root of the repository.')
        sys.exit(1)
    files = v_utils.system('git', 'diff', '--cached', '--name-only').decode("utf-8")
    files = [file.strip() for file in files.split('\n') if file.strip().endswith('.py')]

    if not files:
        sys.exit(0)

    args = ['autopep8', '--in-place']

    args.extend(files)
    output = v_utils.system(*args, cwd=cwd)
    if output:
        print(output.decode("utf-8"),)
        sys.exit(1)
    sys.exit(0)


if __name__ == '__main__':
    main()



import os
import shutil
import tempfile
import unittest
import contextlib

import vtx_common.utils as v_utils

class TestUtils(unittest.TestCase):

    @contextlib.contextmanager
    def getTempdir(self):
        tempdir = tempfile.mkdtemp()
        try:
            yield tempdir
        finally:
            shutil.rmtree(tempdir)

    def test_gitdir(self):

        with self.getTempdir() as dirn:
            self.assertFalse(v_utils.reqGitDir(dirn))
            os.makedirs(os.path.join(dirn, '.git'))
            self.assertTrue(v_utils.reqGitDir(dirn))

    def test_system(self):
        cwd = os.getcwd()
        buf = v_utils.system('pwd')
        system_pwd = buf.decode()
        system_pwd = system_pwd.strip()
        self.assertEqual(cwd, system_pwd)



import os
import subprocess


from typing import ByteString, AnyStr

def system(*args, **kwargs) -> bytes:
    '''Simple subprocess wrapper'''
    kwargs.setdefault('stdout', subprocess.PIPE)
    proc = subprocess.Popen(args, **kwargs)
    out, err = proc.communicate()
    return out

def reqGitDir(cwd: AnyStr =None) -> bool:
    '''Require the given directory to have a .git directory in it.'''
    if not cwd:
        cwd = os.getcwd()
    gitdir = os.path.join(cwd, '.git')
    if os.path.isdir(gitdir):
        return True
    return False



##############################################################################
# The following are touched during the release process by bumpversion.
# Do not modify these directly.
from vtx_common.version import version as _version
from vtx_common.version import verstring as _verstring



#!/usr/bin/env python
"""
Copy this file to .git/hooks/pre-commit in order to have the hooks run when doing a git commit action.

Requires pycodestyle and nbstripout to be installed.

Forked from https://gist.github.com/810399
Updated from https://github.com/cbrueffer/pep8-git-hook
"""
from __future__ import print_function
import os
import shutil
import sys
import tempfile

import vtx_common.utils as v_utils

def main():
    lint_python()

def lint_python():
    gitdir = v_utils.system('git', 'rev-parse', '--show-toplevel').decode('utf-8').strip()
    files = v_utils.system('git', 'diff', '--cached', '--name-only').decode('utf-8')
    pyfiles = [file.strip() for file in files.split('\n') if file.strip().endswith('.py')]

    if pyfiles:
        print('pre-commit - running pycodestyle against python files.')
        tempdir = tempfile.mkdtemp()
        for name in pyfiles:
            filename = os.path.join(tempdir, name)
            filepath = os.path.dirname(filename)

            if not os.path.exists(filepath):
                os.makedirs(filepath)
            with open(filename, 'w') as f:
                v_utils.system('git', 'show', ':' + name, stdout=f)

        args = ['pycodestyle', f'--config={gitdir}/setup.cfg']
        args.append('.')
        output = v_utils.system(*args, cwd=tempdir)
        shutil.rmtree(tempdir)
        if output:
            print('PEP8 style violations have been detected.  Please fix them\n'
                  'or force the commit with "git commit --no-verify".\n')
            print(output.decode('utf-8'),)
            sys.exit(1)

    sys.exit(0)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
import os
import sys
from setuptools import setup, find_packages
from setuptools.command.install import install

VERSION = '0.0.1a'

class VerifyVersionCommand(install):
    """Custom command to verify that the git tag matches our version"""
    description = 'verify that the git tag matches our version'

    def run(self):
        tag = os.getenv('CIRCLE_TAG', '')
        tag = tag.lstrip('v')

        if tag != VERSION:
            info = f"Git tag: {tag} does not match the version of this app: {VERSION}"
            sys.exit(info)

setup(
    name='vtx-common',
    version=VERSION,
    description='Vertex project tools to assist with packaging.',
    author='The Vertex Project LLC',
    author_email='epiphyte+tools@vertex.link',
    url='https://github.com/vertexproject/vertex-tools-common',
    license='Apache License 2.0',

    packages=find_packages(exclude=['scripts',
                                    ]),

    include_package_data=True,

    install_requires=[
        'PyGithub==1.53',
        'pytest>=5.0.0,<6.0.0',
        'autopep8>=1.5.3,<2.0.0',
        'pytest-cov>=2.9.0,<3.0.0',
        'pycodestyle>=2.6.0,<3.0.0',
        'bump2version>=1.0.0,<1.1.0',
        'pytest-xdist>=1.32.0,<2.0.0',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',

        'License :: OSI Approved :: Apache Software License',

        'Topic :: System :: Clustering',
        'Topic :: System :: Distributed Computing',
        'Topic :: System :: Software Distribution',

        'Programming Language :: Python :: 3.7',
    ],
    cmdclass={
        'verify': VerifyVersionCommand,
    },
)



import re
import os
import sys
import logging
import argparse
import collections

import github

HEADER_RE = r'v[0-9]+\.[0-9]+\.[0-9]+((a|b|rc)[0-9]*)?\s-\s20[0-9]{2}-[0-9]{2}-[0-9]{2}'
PASSLINE = r'^=.*$'
SEMVER_RE = r'v[0-9]+\.[0-9]+\.[0-9]+(?P<pre>((a|b|rc)[0-9]*)?)'

logger = logging.getLogger(__name__)

def get_parser():
    pars = argparse.ArgumentParser()
    pars.add_argument('-g', '--github-token', dest='gittokenvar', default='GITHUB_TOKEN', type=str,
                      help='Environment variable to pull the github token from.')
    pars.add_argument('-u', '--github-user', dest='gituservar', default='CIRCLE_PROJECT_USERNAME', type=str,
                      help='Environment variable to pull the github user from')
    pars.add_argument('-r', '--github-repo', dest='gitrepovar', default='CIRCLE_PROJECT_REPONAME', type=str,
                      help='Environment variable to pull the github repo from')
    pars.add_argument('-e', '--tagvar', dest='tagvar', default='CIRCLE_TAG', type=str,
                      help='Environment variable to pull the tag from.')
    pars.add_argument('-c', '--changelog', dest='changelog', default='./CHANGELOG.rst',
                      help='Path to changelog file to process')
    return pars

def parse_changelog(s: str) -> dict:
    curv = None
    v2line = collections.defaultdict(list)
    for line in s.split('\n'):
        if re.match(HEADER_RE, line):
            curv = line.split(' ', 1)[0]
            continue
        if re.match(PASSLINE, line):
            continue
        if curv:
            v2line[curv].append(line)

    ret = {}
    for k, v in v2line.items():
        lines = '\n'.join(v)
        ret[k] = lines.strip()

    return ret

def main(argv):
    pars = get_parser()
    opts = pars.parse_args(argv)

    tag = os.getenv(opts.tagvar, '')
    if not tag:
        logger.error('No tag found')
        return 1

    logger.info(f'envar {opts.tagvar} resolved to {tag}')
    m = re.search(SEMVER_RE, tag)
    if not m:
        logger.error('tag does not match semver regex')
        return 1
    is_prerelease = False
    if m.groupdict().get('pre'):
        is_prerelease = True

    gh_token = os.getenv(opts.gittokenvar, '')
    if not gh_token:
        logger.error('No github token found')
        return 1
    gh_username = os.getenv(opts.gituservar, '')
    if not gh_username:
        logger.error('No github user found')
        return 1
    gh_repo = os.getenv(opts.gitrepovar, '')
    if not gh_repo:
        logger.error('No github repo found')
        return 1

    raw_changelog = open(opts.changelog, 'rb').read().decode()
    parsed_logs = parse_changelog(raw_changelog)

    target_log = parsed_logs.get(tag)
    if not target_log:
        logger.error(f'Unable to find logs for tag [{tag}]')
        # It's possible for pre-release tags to end up without a changelog.
        # This condition should not end up failing a CI pipeline.
        return 0
    logger.info(f'Found changelogs for [{tag}]')
    for line in target_log.split('\n'):
        logger.debug(line)

    gh = github.Github(gh_token)

    gh_repo_path = f'{gh_username}/{gh_repo}'
    logger.info(f'Getting github repo for {gh_repo_path}')
    repo = gh.get_repo(gh_repo_path)

    logger.info('Making github release')
    release = repo.create_git_release(tag=tag,
                                      name=tag,
                                      draft=False,
                                      message=target_log,
                                      prerelease=is_prerelease,
                                      )
    logger.info(f'Made github release {release}')

    return 0

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG)
    sys.exit(main(sys.argv[1:]))
